@@ -23,16 +23,23 @@ NUML = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9']
 ENRICHMENTPERCENTS = {"1": [100], "2": [100], "3": [100],
                       "1-2": [50, 50], "1-3": [50, 50], "2-3": [50, 50], "1-2-3": [33.3, 33.3, 33.4]}
 
-ENRICHMENTCOLORS = {"1": ["Red"], "2": ["Green"], "3": ["Blue"],
-                    "1-2": ["Red", "Green"], "1-3": ["Red", "Blue"], "2-3": ["Blue", "Green"], "1-2-3": ["Red", "Blue", "Green"]}
+ENRICHCOLOR1 = "Red"
+ENRICHCOLOR2 = "Green"
+ENRICHCOLOR3 = "Blue"
+
+# ENRICHMENTCOLORS = {"1": ["Red"], "2": ["Green"], "3": ["Blue"],
+#                     "1-2": ["Red", "Green"], "1-3": ["Red", "Blue"], "2-3": ["Blue", "Green"], "1-2-3": ["Red", "Blue", "Green"]}
 
 SUPPORTEDFORMATS = ['png', 'pdf', 'svg']
 
 
 class GOTrees():
-    def __init__(self, outputRoot, canonicalEnrichment=''):
+    def __init__(self, outputRoot, canonicalEnrichment='', displayedEnrichmentColors=[ENRICHCOLOR1, ENRICHCOLOR2, ENRICHCOLOR3]):
         self.outputRoot = outputRoot
         self.canonicalEnrichment = canonicalEnrichment
+        self.ENRICHMENTCOLORS = {"1": [displayedEnrichmentColors[0]], "2": [displayedEnrichmentColors[1]], "3": [displayedEnrichmentColors[2]],
+                                 "1-2": [displayedEnrichmentColors[0], displayedEnrichmentColors[1]], "1-3": [displayedEnrichmentColors[0], displayedEnrichmentColors[2]], "2-3": [displayedEnrichmentColors[1], displayedEnrichmentColors[2]], "1-2-3": [displayedEnrichmentColors[0], displayedEnrichmentColors[1], displayedEnrichmentColors[2]]}
+
         self.enrichmentsL = []
 
     def selectSubTrees(self):
@@ -160,7 +167,6 @@ class GOTrees():
         subrootColoringL = segmentColorDict.keys()
         for n in tree.traverse():
             if str(n.name) in subrootColoringL:
-                print(n.name)
                 currentColor = segmentColorDict[str(n.name)]
                 nst1 = NodeStyle()
                 nst1["bgcolor"] = currentColor
@@ -311,96 +317,73 @@ class GOTrees():
                         # makeCircularFace(faces, node, "Red")
                         if enrichVis == "pie":
                             makePieChartFace(
-                                faces, node, colors=ENRICHMENTCOLORS["1"], percents=ENRICHMENTPERCENTS["1"])
+                                faces, node, colors=self.ENRICHMENTCOLORS["1"], percents=ENRICHMENTPERCENTS["1"])
                         elif enrichVis == "sphere":
                             makeCircularFace(faces, node, "Red")
                 if len(additionalEnrichments) == 1:
                     if str(node.name) in additionalEnrichments[0] and str(node.name) in origEnrichments:
-                        # makeCircularFace(faces, node, ENRICHMENTCOLORS["1-2"])
                         if enrichVis == "pie":
                             makePieChartFace(
-                                faces, node, colors=ENRICHMENTCOLORS["1-2"], percents=ENRICHMENTPERCENTS["1-2"])
+                                faces, node, colors=self.ENRICHMENTCOLORS["1-2"], percents=ENRICHMENTPERCENTS["1-2"])
                         elif enrichVis == "sphere":
                             makeCircularFace(faces, node, "Red")
                             makeCircularFace(faces, node, "Green")
                     elif str(node.name) in origEnrichments:
-                        # makeCircularFace(faces, node, ENRICHMENTCOLORS["1"])
                         if enrichVis == "pie":
                             makePieChartFace(
-                                faces, node, colors=ENRICHMENTCOLORS["1"], percents=ENRICHMENTPERCENTS["1"])
+                                faces, node, colors=self.ENRICHMENTCOLORS["1"], percents=ENRICHMENTPERCENTS["1"])
                         elif enrichVis == "sphere":
                             makeCircularFace(faces, node, "Red")
                     elif str(node.name) in additionalEnrichments[0]:
                         # makeCircularFace(faces, node, ENRICHMENTCOLORS["2"])
                         if enrichVis == "pie":
                             makePieChartFace(
-                                faces, node, colors=ENRICHMENTCOLORS["2"], percents=ENRICHMENTPERCENTS["2"])
+                                faces, node, colors=self.ENRICHMENTCOLORS["2"], percents=ENRICHMENTPERCENTS["2"])
                         elif enrichVis == "sphere":
                             makeCircularFace(faces, node, "Green")
 
                 if len(additionalEnrichments) == 2:
                     if str(node.name) in origEnrichments:
                         if (str(node.name) in additionalEnrichments[0]) and (str(node.name) in additionalEnrichments[1]):
-                            # if (str(node.name) in additionalEnrichments[0]) and (str(node.name) in origEnrichments) and (str(node.name) in additionalEnrichments[1]):
-                            print(node.name)
-                            print("1-2-3")
-                            # makeCircularFace(
-                            #     faces, node, ENRICHMENTCOLORS["1-2-3"])
                             if enrichVis == "pie":
                                 makePieChartFace(
-                                    faces, node, colors=ENRICHMENTCOLORS["1-2-3"], percents=ENRICHMENTPERCENTS["1-2-3"])
+                                    faces, node, colors=self.ENRICHMENTCOLORS["1-2-3"], percents=ENRICHMENTPERCENTS["1-2-3"])
                             elif enrichVis == "sphere":
                                 makeCircularFace(faces, node, "Red")
                                 makeCircularFace(faces, node, "Green")
                                 makeCircularFace(faces, node, "Blue")
                         elif str(node.name) in additionalEnrichments[0]:
-                            print(node.name)
-                            print("1-2")
                             if enrichVis == "pie":
                                 makePieChartFace(
-                                    faces, node, colors=ENRICHMENTCOLORS["1-2"], percents=ENRICHMENTPERCENTS["1-2"])
+                                    faces, node, colors=self.ENRICHMENTCOLORS["1-2"], percents=ENRICHMENTPERCENTS["1-2"])
                             elif enrichVis == "sphere":
                                 makeCircularFace(faces, node, "Red")
                                 makeCircularFace(faces, node, "Green")
                         elif str(node.name) in additionalEnrichments[1]:
-                            # if (str(node.name) in additionalEnrichments[1]) and (str(node.name) in origEnrichments) and (not str(node.name) in additionalEnrichments[0]):
-                            # makeCircularFace(faces, node, ENRICHMENTCOLORS["1-3"])
-                            print(node.name)
-                            print("1-3")
                             if enrichVis == "pie":
                                 makePieChartFace(
-                                    faces, node, colors=ENRICHMENTCOLORS["1-3"], percents=ENRICHMENTPERCENTS["1-3"])
+                                    faces, node, colors=self.ENRICHMENTCOLORS["1-3"], percents=ENRICHMENTPERCENTS["1-3"])
                             elif enrichVis == "sphere":
                                 makeCircularFace(faces, node, "Red")
                                 makeCircularFace(faces, node, "Blue")
                     elif str(node.name) in additionalEnrichments[0]:
                         if str(node.name) in additionalEnrichments[1]:
-                            # if (str(node.name) in additionalEnrichments[0]) and (not str(node.name) in origEnrichments) and (str(node.name) in additionalEnrichments[1]):
-                            # makeCircularFace(faces, node, ENRICHMENTCOLORS["2-3"])
-                            print(node.name)
-                            print("2-3")
                             if enrichVis == "pie":
                                 makePieChartFace(
-                                    faces, node, colors=ENRICHMENTCOLORS["2-3"], percents=ENRICHMENTPERCENTS["2-3"])
+                                    faces, node, colors=self.ENRICHMENTCOLORS["2-3"], percents=ENRICHMENTPERCENTS["2-3"])
                             elif enrichVis == "sphere":
                                 makeCircularFace(faces, node, "Blue")
                                 makeCircularFace(faces, node, "Green")
                         else:
-                            print(node.name)
-                            print("2 WHAT THE ACTUAL")
-                            # makeCircularFace(faces, node, ENRICHMENTCOLORS["2"])
                             if enrichVis == "pie":
                                 makePieChartFace(
-                                    faces, node, colors=ENRICHMENTCOLORS["2"], percents=ENRICHMENTPERCENTS["2"])
+                                    faces, node, colors=self.ENRICHMENTCOLORS["2"], percents=ENRICHMENTPERCENTS["2"])
                             elif enrichVis == "sphere":
                                 makeCircularFace(faces, node, "Green")
                     else:
-                        print(node.name)
-                        print("3")
-                        # makeCircularFace(faces, node, ENRICHMENTCOLORS["3"])
                         if enrichVis == "pie":
                             makePieChartFace(
-                                faces, node, colors=ENRICHMENTCOLORS["3"], percents=ENRICHMENTPERCENTS["3"])
+                                faces, node, colors=self.ENRICHMENTCOLORS["3"], percents=ENRICHMENTPERCENTS["3"])
                         elif enrichVis == "sphere":
                             makeCircularFace(faces, node, "Blue")
             if "GO:"+str(node.name) in currentLegitDesL:
@@ -417,11 +400,6 @@ class GOTrees():
                                       position='branch-right')
                 else:
                     if str(node.name) in additionalEnrichments[0] or str(node.name) in additionalEnrichments[1] or str(node.name) in origEnrichments or str(node.name) in extendedBGAdditionalEnrichments:
-                        print(node.name)
-                        print("In additional?", str(str(node.name)
-                                                    in additionalEnrichments[0]))
-                        print("In original?", str(
-                            str(node.name) in origEnrichments))
                         name_face = TextFace("▓▓▓▓▓", fgcolor="Purple",
                                              fsize=math.sqrt(int(nodeCounter))*0.001)
                         node.add_face(name_face, column=0,
@@ -448,13 +426,13 @@ class GOTrees():
         ts.legend.add_face(
             TextFace(legendText, fsize=int(totalNumPathways)), column=0)
         ts.legend.add_face(
-            TextFace("●: "+enrichmentNameL[0], fsize=int(totalNumPathways), fgcolor=ENRICHMENTCOLORS["1"][0]), column=0)
+            TextFace("●: "+enrichmentNameL[0], fsize=int(totalNumPathways), fgcolor=self.ENRICHMENTCOLORS["1"][0]), column=0)
         if enrichment >= 2:
             ts.legend.add_face(TextFace("●: "+enrichmentNameL[1], fsize=int(
-                totalNumPathways), fgcolor=ENRICHMENTCOLORS["2"][0]), column=0)
+                totalNumPathways), fgcolor=self.ENRICHMENTCOLORS["2"][0]), column=0)
         if enrichment == 3:
             ts.legend.add_face(TextFace("●: "+enrichmentNameL[2], fsize=int(
-                totalNumPathways), fgcolor=ENRICHMENTCOLORS["3"][0]), column=0)
+                totalNumPathways), fgcolor=self.ENRICHMENTCOLORS["3"][0]), column=0)
         ts.legend_position = 4
 
         # output
@@ -548,29 +526,7 @@ class GOTrees():
             print(
                 "------------------------------------------------------------------------------")
             print("Preparing to draw subtree with root "+currentSubtreeRoot+".")
-            # # for enrichment
-            # enrichmentFileL = []
-            # enrichmentNameL = [firstEnrichmentName]
-            # if enrichment != 1:
-            #     for i in range(enrichment-1):
-            #         enrichmentFileL, enrichmentNameL = getSingleEnrichmentFile(
-            #             i, enrichmentFileL, enrichmentNameL)
-            #         print(enrichmentFileL)
-            #     if len(enrichmentFileL) != enrichment-1:
-            #         raise Exception(
-            #             "Number of inputted enrichment files does not match the number of enrichment inputted as the argument:", enrichment)
-            # print(
-            #     "------------------------------------------------------------------------------")
-            # print("Now start to input background enrichments")
-            # if numOfBackgroundEnrichments != 0:
-            #     bgenrichmentFileL = []
-            #     bgenrichmentNameL = []
-            #     for i in range(numOfBackgroundEnrichments):
-            #         bgenrichmentFileL, bgenrichmentNameL = getSingleEnrichmentFile(
-            #             i, bgenrichmentFileL, bgenrichmentNameL, bg=True)
-            #     if len(bgenrichmentFileL) != numOfBackgroundEnrichments:
-            #         raise Exception(
-            #             "Number of inputted enrichment files does not match the number of enrichment inputted as the argument:", enrichment)
+
             # for segment coloring
             segmentColorDict = {}
             if select == "all":
